% Function computes the objective measuring the differences
% in the enzymes activities.

function [fo] = opt_fun2(g,J1,J2,Srx,dir1,dir2,go,kT,L);

[m,n] = size(Srx);
g1 = g(1:m);
g2 = g((m+1):(2*m));
c1 = exp((g1-go')./kT); 
c2 = exp((g2-go')./kT); 

dG1 = Srx'*g1;
dG2 = Srx'*g2;
dGo = Srx'*go';
% ANT transporter dependence on membrane potential:
dGo(39) = dGo(39) + go(46);
dG1(39) = dG1(39) + go(46);
dG2(39) = dG2(39) + go(46);
% pH dependence on Pi transport:
dG1(40) = dG1(40) + kT*log(c1(46));
dG2(40) = dG2(40) + kT*log(c2(46));
Keq = exp( - dGo ./ kT );

% Intermediate calculations:
Srxp = Srx.*(Srx>0);
Srxn = -Srx.*(Srx<0);
cTr1 = prod((ones(n,1)*c1')'.^Srxp);
cTl1 = prod((ones(n,1)*c1')'.^Srxn);
cTr2 = prod((ones(n,1)*c2')'.^Srxp);
cTl2 = prod((ones(n,1)*c2')'.^Srxn);
cTr1(40) = cTr1(40)*c1(46);
cTr2(40) = cTr2(40)*c2(46);
h1 = (Keq.*cTl1' - cTr1');
h2 = (Keq.*cTl2' - cTr2');
icm = ((abs(dG1)>1e-6).*(abs(dG2)>1e-6));

% Activities:
X1 = max( icm.*J1(1:n)./h1, 1e-15);
X2 = max( icm.*J2(1:n)./h2, 1e-15);

% Objective:
ix = [(1:15) (17:40)];
fo = sum( ((X1(ix)-X2(ix)).^2)./max(X1(ix),X2(ix)).^2 );
